"use strict";
exports.__esModule = true;
var axis_1 = require("../utils/axis");
var data_1 = require("../utils/data");
var const_1 = require("../const");
var line_1 = require("../utils/line");
var drawPillarHorizontal = function (graph, center, len) {
    var left = 1, right = len;
    (0, line_1.drawLine)(graph, const_1.UNDERSCORE, [center - 1, left], [center - 1, right]);
    (0, line_1.drawLine)(graph, const_1.UNDERSCORE, [center, left], [center, right]);
    graph[center][right + 1] = const_1.VERTICAL;
};
var drawPillarVertical = function (graph, center, len) {
    var bottom = graph.length - 2;
    var top = bottom - len + 1;
    (0, line_1.drawLine)(graph, const_1.VERTICAL, [bottom, center - 1], [top, center - 1]);
    (0, line_1.drawLine)(graph, const_1.VERTICAL, [bottom, center + 1], [top, center + 1]);
    graph[top - 1][center] = const_1.UNDERSCORE;
    graph[bottom + 1][center] = const_1.POINT;
};
/**
 * 绘制柱状图，默认纵向
 */
var drawBar = function (option) {
    var _a, _b;
    var _c = option.size, _d = _c === void 0 ? {} : _c, _e = _d.width, width = _e === void 0 ? 40 : _e, _f = _d.height, height = _f === void 0 ? 10 : _f, _g = option.direction, direction = _g === void 0 ? "y" : _g, data = option.data;
    // 如果传入的width和height不符合最小宽高要求，重新赋值并提示
    var minWidth = data.length * 3 + 3;
    var minHeight = data.length * 3 + 2;
    if (direction === "x" && height < minHeight) {
        height = minHeight;
        if ((_a = option === null || option === void 0 ? void 0 : option.size) === null || _a === void 0 ? void 0 : _a.height) {
            console.log("height is not enough, change to ".concat(height));
        }
    }
    if (direction === "y" && width < minWidth) {
        width = minWidth;
        if ((_b = option === null || option === void 0 ? void 0 : option.size) === null || _b === void 0 ? void 0 : _b.width) {
            console.log("width is not enough, change to ".concat(width));
        }
    }
    var graph = (0, data_1.initArr)(width, height);
    if (direction === "x") {
        (0, axis_1.drawAxisHorizontal)(graph, width, height);
        // 柱状图的值格式化
        var normalized_1 = (0, data_1.valueScale)([1, width - 2], data);
        // 坐标在纵轴上格式化
        var coordinate = (0, data_1.coordinateScale)([1, height - 1], data.map(function (item, index) { return index + 1; }));
        coordinate.forEach(function (center, index) {
            drawPillarHorizontal(graph, center, normalized_1[index]);
        });
    }
    else {
        (0, axis_1.drawAxisVertical)(graph, width, height);
        var normalized_2 = (0, data_1.valueScale)([1, height - 2], data);
        var coordinate = (0, data_1.coordinateScale)([1, width - 1], data.map(function (item, index) { return index + 1; }));
        coordinate.forEach(function (center, index) {
            drawPillarVertical(graph, center, normalized_2[index]);
        });
    }
    return graph;
};
exports["default"] = drawBar;
